<?php

return [
    'Names' => [
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermudian Dollar',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'Belarusian New Rouble (1994–1999)',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'Belarusian Rouble',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'Belarusian Rouble (2000–2016)',
        ],
        'JPY' => [
            0 => 'JP¥',
            1 => 'Japanese Yen',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'Latvian Rouble',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Russian Rouble',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'Russian Rouble (1991–1998)',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'St Helena Pound',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'Tajikistani Rouble',
        ],
        'USD' => [
            0 => 'US$',
            1 => 'US Dollar',
        ],
    ],
];
